@@ -1,4 +1,6 @@
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 
 from .exceptions import BadResponseException, MalformedResponseException
+from .models.batch import Batch, BatchSet
+from .models.word import Word, WordSet
 from .requests import get_batches, get_words
